@@ -1,8 +1,9 @@
 """
 
 """
+import pathlib
 
-__version__ = "0.1.0"
+__version__ = (pathlib.Path(__file__).parent.resolve() / 'VERSION').read_text(encoding='utf-8').strip()
 __author__ = 'Ido Carmi'
 __credits__ = 'hermetric.com'
 
